Functional Group Factories
==========================

.. toctree::
  :maxdepth: 1

  Overview and Examples <_autosummary/stk.FunctionalGroupFactory>
  Alcohol Factory <_autosummary/stk.AlcoholFactory>
  Aldehyde Factory <_autosummary/stk.AldehydeFactory>
  Amide Factory <_autosummary/stk.AmideFactory>
  Boronic Acid Factory <_autosummary/stk.BoronicAcidFactory>
  Bromo Factory <_autosummary/stk.BromoFactory>
  Carboxylic Acid Factory <_autosummary/stk.CarboxylicAcidFactory>
  Dibromo Factory <_autosummary/stk.DibromoFactory>
  Difluoro Factory <_autosummary/stk.DifluoroFactory>
  Diol Factory <_autosummary/stk.DiolFactory>
  Fluoro Factory <_autosummary/stk.FluoroFactory>
  Iodo Factory <_autosummary/stk.IodoFactory>
  Primary Amino Factory <_autosummary/stk.PrimaryAminoFactory>
  Ring Amine Factory <_autosummary/stk.RingAmineFactory>
  Secondary Amino Factory <_autosummary/stk.SecondaryAminoFactory>
  SMARTS Functional Group Factory <_autosummary/stk.SmartsFunctionalGroupFactory>
  Terminal Alkene Factory <_autosummary/stk.TerminalAlkeneFactory>
  Terminal Alkyne Factory <_autosummary/stk.TerminalAlkyneFactory>
  Thioacid Factory <_autosummary/stk.ThioacidFactory>
  Thiol Factory <_autosummary/stk.ThiolFactory>
